1
0
mirror of https://git.FreeBSD.org/ports.git synced 2025-01-06 06:30:19 +00:00

www/Stikked: Update to 0.14.0

This commit is contained in:
Dan Langille 2022-06-18 12:54:36 +00:00
parent efc46764a0
commit 8caa9136c6
5 changed files with 25 additions and 38 deletions

View File

@ -1,8 +1,7 @@
# Created by: Dan Langille <dvl@FreeBSD.org>
PORTNAME= Stikked
DISTVERSION= 0.13.0
PORTREVISION= 2
DISTVERSION= 0.14.0
CATEGORIES= www
MAINTAINER= dvl@FreeBSD.org

View File

@ -1,3 +1,3 @@
TIMESTAMP = 1538678447
SHA256 (claudehohl-Stikked-0.13.0_GH0.tar.gz) = bd6695268a899a1d562b0deff1b67e0522f0e0ef818413e392cc182d3aa82566
SIZE (claudehohl-Stikked-0.13.0_GH0.tar.gz) = 10644340
TIMESTAMP = 1655555745
SHA256 (claudehohl-Stikked-0.14.0_GH0.tar.gz) = 50a2540c234484b44dba713553c15f3a96da00cb7067e976e9ad49c3be1eec5a
SIZE (claudehohl-Stikked-0.14.0_GH0.tar.gz) = 10648711

View File

@ -1,6 +1,6 @@
--- htdocs/application/config/stikked.php.dist.orig 2017-12-13 15:26:05 UTC
--- htdocs/application/config/stikked.php.dist.orig 2019-11-24 16:10:45 UTC
+++ htdocs/application/config/stikked.php.dist
@@ -17,6 +17,19 @@ $config['site_name'] = 'Stikked';
@@ -19,6 +19,19 @@ $config['site_name'] = 'Stikked';
$config['base_url'] = 'https://yourpastebin.com/';
/**

View File

@ -1,21 +1,21 @@
--- htdocs/application/models/Pastes.php.orig 2017-12-13 15:21:30 UTC
--- misc.c.orig 2019-08-01 13:54:47 UTC
+++ misc.c
@@ -62,7 +62,8 @@ void monitorhook(struct udata *userdata, time_t now, c
static UT_string *us = NULL;
utstring_renew(us);
- utstring_printf(us, "%ld %s\n", now, topic);
+ utstring_printf(us, "%ld %s\n", (long)now, topic);
+
snprintf(mpath, sizeof(mpath), "%s/monitor", STORAGEDIR);
safewrite(mpath, UB(us));
--- htdocs/application/models/Pastes.php.orig 2022-06-18 12:47:43 UTC
+++ htdocs/application/models/Pastes.php
@@ -56,8 +56,16 @@ class Pastes extends CI_Model
{
$data['created'] = time();
@@ -32,8 +32,16 @@ class Pastes extends CI_Model
{
$data['created'] = time();
- //this is SO evil… saving the «raw» data with htmlspecialchars :-( (but I have to leave this, because of backwards-compatibility)
- $data['raw'] = htmlspecialchars($this->_strip_bad_multibyte_chars($this->input->post('code')));
+ if ($this->config->item('true_paste'))
+ {
+ // save the paste as supplied
+ $data['raw'] = $this->input->post('code');
+ }
+ else
+ {
+ //this is SO evil… saving the «raw» data with htmlspecialchars :-( (but I have to leave this, because of backwards-compatibility)
+ $data['raw'] = htmlspecialchars($this->_strip_bad_multibyte_chars($this->input->post('code')));
+ }
$data['lang'] = htmlspecialchars($this->input->post('lang'));
$data['replyto'] = ($this->input->post('reply') === null ? '0' : $this->input->post('reply'));
- //this is SO evil… saving the «raw» data with htmlspecialchars :-( (but I have to leave this, because of backwards-compatibility)
- $data['raw'] = htmlspecialchars($this->_strip_bad_multibyte_chars($this->input->post('code')));
+ if ($this->config->item('true_paste'))
+ {
+ // save the paste as supplied
+ $data['raw'] = $this->input->post('code');
+ }
+ else
+ {
+ //this is SO evil… saving the «raw» data with htmlspecialchars :-( (but I have to leave this, because of backwards-compatibility)
+ $data['raw'] = htmlspecialchars($this->_strip_bad_multibyte_chars($this->input->post('code')));
+ }
$data['lang'] = htmlspecialchars($this->input->post('lang'));
$data['replyto'] = ($this->input->post('reply') === null ? '0' : $this->input->post('reply'));

View File

@ -1,12 +0,0 @@